@@ -17,6 +17,7 @@ static void zuser_free_locs(zuser *user);
 struct _zuser
 {
   GString *name;
+  GString *principal;
   int numlocs;
   ZLocations_t *locs;
 };
@@ -27,9 +28,29 @@ Code_t ZGetLocations(ZLocations_t location[], int *numloc);
 zuser *zuser_new(const GString *name)
 {
   zuser *user = g_new(zuser, 1);
-  user->name = g_string_new(name->str);
+
+  /* Split name into at most two bits on @ signs. */
+  gchar **nparts = g_strsplit(name->str, "@", 2);
+  /* Is there a second part? */
+  if (nparts[1] != NULL)
+  {
+    /* Okay: name is the full name, nparts[0] is the abbrev name. */
+    user->name = g_string_new(nparts[0]);
+    user->principal = g_string_new(name->str);
+  }
+  else
+  {
+    /* No @, use the default realm for the principal. */
+    user->name = g_string_new(name->str);
+    user->principal = g_string_new("");
+    g_string_sprintf(user->principal, "%s@%s", user->name->str, ZGetRealm());
+  }
+  g_strfreev(nparts);
+    
+  /* Also set up location stuff. */
   user->numlocs = 0;
   user->locs = NULL;
+
   return user;
 }
 
@@ -52,16 +73,21 @@ GString *zuser_name(const zuser *user)
   return g_string_new(user->name->str);
 }
 
-void zuser_update(zuser *user)
+GString *zuser_principal(const zuser *user)
 {
-  GString *fullname = g_string_new("");
+  g_assert(user != NULL);
+  g_assert(user->principal != NULL);
+  return g_string_new(user->principal->str);
+}
+
+void zuser_update(zuser *user)
+{  
   int cresult, numlocs;
 
-  g_assert(user->name != NULL);
+  g_assert(user != NULL);
+  g_assert(user->principal != NULL);
   
-  g_string_sprintf(fullname, "%s@%s", user->name->str, ZGetRealm());
-  
-  cresult = ZLocateUser(fullname->str, &numlocs, ZAUTH);
+  cresult = ZLocateUser(user->principal->str, &numlocs, ZAUTH);
   if (cresult != ZERR_NONE)
   {
     g_error("Trying to update users: %s", error_message(cresult));
@@ -97,7 +123,8 @@ void zuser_update(zuser *user)
     g_free(user->locs);
     user->locs = NULL;
     user->numlocs = 0;
-    g_error("Trying to update %s: %s", fullname->str, error_message(cresult));
+    g_error("Trying to update %s: %s", user->principal->str,
+            error_message(cresult));
   }
 }
 
