@@ -1,7 +1,7 @@
 /*
  * gtk_anyone.c: Show the user tree as a Gtk+ widget
  * David Maze <dmaze@mit.edu>
- * $Id: gtkanyone.c,v 1.24 2001/12/11 04:21:46 dmaze Exp $
+ * $Id: gtkanyone.c,v 1.25 2002/05/13 22:54:31 dmaze Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -264,7 +264,20 @@ static void rebuild_children(GtkAnyone *anyone)
       
       luser = luser->next;
       /* We often lose here; why? */
-      g_assert(luser != NULL);
+      if (luser == NULL)
+      {
+        GString *tname = zuser_principal(target);
+        GString *gname = zgroup_name(anyone->group);
+        g_warning("BUG: group update failure\n"
+                  "We were looking for %s in the %s group, but didn't find it.\n"
+                  "Proceeding anyways, in the hopes that recovery might be\n"
+                  "possible.  If you have any insight as to why this happens,\n"
+                  "please tell dmaze@mit.edu.\n",
+                  tname->str, gname->str);
+        g_string_free(tname, TRUE);
+        g_string_free(gname, TRUE);
+        return;
+      }
       user = luser->data;
     }
     /* Now we have a guarantee that user == target. */
@@ -284,6 +297,7 @@ static void rebuild_children(GtkAnyone *anyone)
     {
       /* Nope, not around.  Delete their widget item. */
       gtk_container_remove(GTK_CONTAINER(anyone), widget);
+      pos--;
     }
   }
 
